## MAC OS X

## Python Installation

Go to [python site](https://www.python.org/) and navigate to the `Downloads` page

<img src="./document_images/python_download_mac.png" alt="image-20250823111349808" style="zoom:33%;" />

Download python.

You should see an installation program icon in your task bar <img src="./document_images/python_app_image_icon.png" alt="image-20250823111819678" style="zoom:25%;" />

Double click this icon, and accept all default options.

Once installation is complete, you should see the following 'finder' window pop-up

<img src="./document_images/python_app_folder.png" alt="image-20250823112048447" style="zoom: 25%;" />

**Double click the "update Shell" icon**

### Validation

Use the search tool (Command-spacebar) open a terminal window

<img src="./document_images/search_terminal.png" alt="image-20250823110447048" style="zoom:33%;" />

Type the following in the terminal window

```bash
python3 --version
```

The version number should be the same python that you installed

<img src="./document_images/python_version_mac.png" alt="image-20250823112346490" style="zoom:33%;" />

## Application Installation

Use the search tool (Command-spacebar) open a terminal window

<img src="./document_images/search_terminal.png" alt="image-20250823110447048" style="zoom:33%;" />

Type the following in the terminal window

```bash
python3 -m pip install scheduling_and_allocation
```

## Running the program(s)

Use the search tool (Command-spacebar) to open a terminal window

Type the following in the terminal window

```bash
Scheduler
```

or

```python
Allocation
```

